Title: [91588] branches/safari-534.51-branch/Source/WebKit2

Diff

Modified: branches/safari-534.51-branch/Source/WebKit2/ChangeLog (91587 => 91588)


--- branches/safari-534.51-branch/Source/WebKit2/ChangeLog	2011-07-22 19:20:05 UTC (rev 91587)
+++ branches/safari-534.51-branch/Source/WebKit2/ChangeLog	2011-07-22 19:21:09 UTC (rev 91588)
@@ -1,3 +1,21 @@
+2011-07-22  Lucas Forschler  <[email protected]>
+
+    Merged 90851.
+
+    2011-06-22  Jer Noble  <[email protected]>
+
+        Full-screen: Don't change the collectionBehavior of the WebView's NSWindow if not necessary
+        https://bugs.webkit.org/show_bug.cgi?id=63217
+        <rdar://problem/9660291>
+
+        Reviewed by Darin Adler.
+
+        Check to see if the NSWindow hosting the WebView is not on the active space before changing the window's
+        collectionBehavior.
+
+        * UIProcess/mac/WKFullScreenWindowController.mm:
+        (-[WKFullScreenWindowController beganExitFullScreenAnimation]):
+
 2011-07-21  Lucas Forschler  <[email protected]>
 
     Merged 90198.

Modified: branches/safari-534.51-branch/Source/WebKit2/UIProcess/mac/WKFullScreenWindowController.mm (91587 => 91588)


--- branches/safari-534.51-branch/Source/WebKit2/UIProcess/mac/WKFullScreenWindowController.mm	2011-07-22 19:20:05 UTC (rev 91587)
+++ branches/safari-534.51-branch/Source/WebKit2/UIProcess/mac/WKFullScreenWindowController.mm	2011-07-22 19:21:09 UTC (rev 91588)
@@ -324,12 +324,16 @@
         NSWindowAnimationBehavior animationBehavior = [webWindow animationBehavior];
         [webWindow setAnimationBehavior:NSWindowAnimationBehaviorNone];
 #endif
-        // The user may have moved the fullScreen window in Spaces, so temporarily change 
-        // the collectionBehavior of the webView's window:
-        NSWindowCollectionBehavior behavior = [webWindow collectionBehavior];
-        [webWindow setCollectionBehavior:NSWindowCollectionBehaviorCanJoinAllSpaces];
-        [webWindow orderWindow:NSWindowBelow relativeTo:[[self window] windowNumber]];
-        [webWindow setCollectionBehavior:behavior];
+        // If the user has moved the fullScreen window into a new space, temporarily change
+        // the collectionBehavior of the webView's window so that it is pulled into the active space:
+        if (![webWindow isOnActiveSpace]) {
+            NSWindowCollectionBehavior behavior = [webWindow collectionBehavior];
+            [webWindow setCollectionBehavior:NSWindowCollectionBehaviorCanJoinAllSpaces];
+            [webWindow orderWindow:NSWindowBelow relativeTo:[[self window] windowNumber]];
+            [webWindow setCollectionBehavior:behavior];
+        } else
+            [webWindow orderWindow:NSWindowBelow relativeTo:[[self window] windowNumber]];
+
 #if !defined(BUILDING_ON_LEOPARD) && !defined(BUILDING_ON_SNOW_LEOPARD)
         [webWindow setAnimationBehavior:animationBehavior];
 #endif
_______________________________________________
webkit-changes mailing list
[email protected]
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes

Reply via email to